Describe how to install the library for development purposes.

### Run Tests



### Run Elasticsearch Serverless Docker container



### Contributing Code Changes

1. Please make sure you have signed the [Contributor License
   Agreement](http://www.elastic.co/contributor-agreement/). We are not
   asking you to assign copyright to us, but to give us the right to distribute
   your code without restriction. We ask this of all contributors in order to
   assure our users of the origin and continuing existence of the code. You only
   need to sign the CLA once.
2. Rebase your changes. Update your local repository with the most recent code
   from the main `elasticsearch-serverless-python` repository and rebase your branch
   on top of the latest `main` branch.
3. Submit a pull request. Push your local changes to your forked repository
   and [submit a pull request](https://github.com/elastic/elasticsearch-serverless/pulls)
   and mention the issue number if any (`Closes #123`) Make sure that you
   add or modify tests related to your changes so that CI will pass.
4. Sit back and wait. There may be some discussion on your pull request and
   if changes are needed we would love to work with you to get your pull request
   merged into `elasticsearch-serverless-python`.
